@@ -278,25 +278,15 @@ class NFSHelper(NASHelperBase):
                     continue
                 access_to = self._get_parsed_address_or_cidr(
                     access['access_to'])
-                try:
-                    self._ssh_exec(server, ['sudo', 'exportfs', '-u',
-                                            ':'.join((access_to, local_path))])
-                except exception.ProcessExecutionError as e:
-                    if "could not find" in e.stderr.lower():
-                        LOG.debug(
-                            "Client/s with IP address/es %(host)s did not "
-                            "have access to %(share)s. Nothing to deny.",
-                            {'host': access_to, 'share': share_name})
-                    else:
-                        raise
-
+                self._ssh_exec(server, ['sudo', 'exportfs', '-u',
+                               ':'.join((access_to, local_path))])
             if delete_rules:
                 self._sync_nfs_temp_and_perm_files(server)
             for access in add_rules:
                 access_to = self._get_parsed_address_or_cidr(
                     access['access_to'])
                 found_item = re.search(
-                    re.escape(local_path) + '[\s\n]*' + re.escape(access_to),
+                    re.escape(local_path) + r'[\s\n]*' + re.escape(access_to),
                     out)
                 if found_item is not None:
                     LOG.warning("Access rule %(type)s:%(to)s already "
