@@ -108,9 +108,7 @@ class LVMMixin(driver.ExecuteMixin):
                               (self.configuration.lvm_share_volume_group,
                                share_name), run_as_root=True)
         except exception.ProcessExecutionError as exc:
-            err_pattern = re.compile(".*failed to find.*|.*not found.*",
-                                     re.IGNORECASE)
-            if not err_pattern.match(exc.stderr):
+            if "not found" not in exc.stderr:
                 LOG.exception("Error deleting volume")
                 raise
             LOG.warning("Volume not found: %s", exc.stderr)
@@ -225,8 +223,8 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
                                  self.configuration.lvm_share_volume_group,
                                  '--rows', '--units', 'g',
                                  run_as_root=True)
-        total_size = re.findall("VSize\s[0-9.]+g", out)[0][6:-1]
-        free_size = re.findall("VFree\s[0-9.]+g", out)[0][6:-1]
+        total_size = re.findall(r"VSize\s[0-9.]+g", out)[0][6:-1]
+        free_size = re.findall(r"VFree\s[0-9.]+g", out)[0][6:-1]
         return [{
             'pool_name': 'lvm-single-pool',
             'total_capacity_gb': float(total_size),
@@ -244,7 +242,7 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
         return location
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from snapshot."""
         self._allocate_container(share)
         snapshot_device_name = self._get_local_path(snapshot)
@@ -258,11 +256,11 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
         return location
 
     def delete_share(self, context, share, share_server=None):
-        self._unmount_device(share, raise_if_missing=False)
+        self._unmount_device(share)
         self._delete_share(context, share)
         self._deallocate_container(share['name'])
 
-    def _unmount_device(self, share_or_snapshot, raise_if_missing=True):
+    def _unmount_device(self, share_or_snapshot):
         """Unmount the filesystem of a share or snapshot LV."""
         mount_path = self._get_mount_path(share_or_snapshot)
         if os.path.exists(mount_path):
@@ -270,13 +268,9 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
             try:
                 self._execute('umount', '-f', mount_path, run_as_root=True)
             except exception.ProcessExecutionError as exc:
-                if 'device is busy' in exc.stderr.lower():
+                if 'device is busy' in six.text_type(exc):
                     raise exception.ShareBusyException(
                         reason=share_or_snapshot['name'])
-                elif 'not mounted' in exc.stderr.lower():
-                    if raise_if_missing:
-                        LOG.error('Unable to find device: %s', exc)
-                        raise
                 else:
                     LOG.error('Unable to umount: %s', exc)
                     raise
@@ -435,7 +429,7 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
         return {'export_locations': exports}
 
     def delete_snapshot(self, context, snapshot, share_server=None):
-        self._unmount_device(snapshot, raise_if_missing=False)
+        self._unmount_device(snapshot)
 
         super(LVMShareDriver, self).delete_snapshot(context, snapshot,
                                                     share_server)
@@ -497,7 +491,7 @@ class LVMShareDriver(LVMMixin, driver.ShareDriver):
                 mount_path = self._get_mount_path(share)
                 if os.path.exists(mount_path):
                     used_size = (re.findall(
-                        mount_path + "\s*[0-9.]+G", out)[0].
+                        mount_path + r"\s*[0-9.]+G", out)[0].
                         split(' ')[-1][:-1])
                     updated_shares.append({'id': share['id'],
                                            'used_size': used_size,
